// The sample contained herein is provided to you "AS IS".
//
// It is furnished by Add-in Express as a simple example and has not been
// thoroughly tested under all conditions. Add-in Express, therefore, cannot
// guarantee its reliability, serviceability or functionality.

unit uUtils;

interface

uses
  Windows, Dialogs, Excel2000, Office2000, adxxlFormsManager, ActiveX, Forms,
  SysUtils;

type
  ProjectConsts = class
  public
    class function DevCode: string;
    class function HowtoName: string;
    class function ProjectShortName: string;
    class function MessageCaption: string;
    class function HowtoProjectName: string;
    class function CommandBarName: string;
  end;

  Strings = class
    class function AddinModuleOnError: string;
    class function TaskManagerOnError: string;
    class function AllFolders: string;
    class function TheTaskPaneWillHide: string;
    class function DoYouWantShowTaskPane: string;
  end;

  Common = class
  public
    class function CompareADXStrings(str1: string; str2: string): boolean;
    class function IndexOfString(source: string; str: string): integer;
    class procedure ShowError(mes: string);
    class procedure ShowMessage(mes: string);
  end;

  HostVersion = (vUnknown, v2000, v2002, v2003, v2007);

  ExcelUtils = class
  public
    class procedure InitExcelVersion(ExcelApp: ExcelApplication);
    class function ExcelVersion: HostVersion;
  end;



implementation

var
  ExcelUtilsExcelVersion: HostVersion;

const
  adxLCID: Integer = LOCALE_USER_DEFAULT;

{ ProjectConsts }

class function ProjectConsts.CommandBarName: string;
begin
  result := HowtoProjectName;
end;

class function ProjectConsts.DevCode: string;
begin
  result := 'D7';
end;

class function ProjectConsts.HowtoName: string;
begin
  result := 'Controlling the Visibility of the Task Pane';
end;

class function ProjectConsts.HowtoProjectName: string;
begin
  result := ProjectShortName + DevCode;
end;

class function ProjectConsts.MessageCaption: string;
begin
  result := HowtoName;
end;

class function ProjectConsts.ProjectShortName: string;
begin
  result := 'Visibility';
end;

{ Strings }

class function Strings.AddinModuleOnError: string;
begin
  result := 'An error has been handled in the AddinModule.OnError event';
end;

class function Strings.AllFolders: string;
begin
  result := '*';
end;

class function Strings.DoYouWantShowTaskPane: string;
begin
  result := 'Do you want show TadxOlForm?';
end;

class function Strings.TaskManagerOnError: string;
begin
  result := 'An error has been handled in the ADXExcelTaskManager.OnError event';
end;

class function Strings.TheTaskPaneWillHide: string;
begin
  result := 'This operation will to hide the Task Pane.'
    + #13#10 + 'To restore it, click the Restore TadxExcelTaskPane1 button in the command bar';
end;

{ Common }

class function Common.CompareADXStrings(str1, str2: string): boolean;
begin
  result := UpperCase(str1) = UpperCase(str2);
end;

class function Common.IndexOfString(source, str: string): integer;
begin
  result := Pos(str, source);
end;

class procedure Common.ShowError(mes: string);
begin
  MessageBox(0, PChar(mes), PChar(ProjectConsts.MessageCaption), MB_OK or MB_ICONERROR or MB_APPLMODAL);
end;

class procedure Common.ShowMessage(mes: string);
begin
  MessageBox(0, PChar(mes), PChar(ProjectConsts.MessageCaption), MB_OK or MB_APPLMODAL);
end;

{ ExcelUtils }

class procedure ExcelUtils.InitExcelVersion(
  ExcelApp: _Application);
var
  hostVersion: string;
begin
  if (ExcelApp <> nil) then begin
      hostVersion := ExcelApp.Version[adxLCID];

      if (Common.IndexOfString(hostVersion, '9.0') = 1) then begin
        ExcelUtilsExcelVersion := v2000;
      end;

      if (Common.IndexOfString(hostVersion, '10.0') = 1) then begin
        ExcelUtilsExcelVersion := v2002;
      end;

      if (Common.IndexOfString(hostVersion, '11.0') = 1) then begin
        ExcelUtilsExcelVersion := v2003;
      end;

      if (Common.IndexOfString(hostVersion, '12.0') = 1) then begin
        ExcelUtilsExcelVersion := v2007;
      end;
  end;
end;

class function ExcelUtils.ExcelVersion: HostVersion;
begin
  result := ExcelUtilsExcelVersion;
end;





end.
